def get_basic():
    return {
        'Records': [
            {
                'kinesis': {
                    'kinesisSchemaVersion': '1.0',
                    'partitionKey': '1',
                    'sequenceNumber': '49590338271490256608559692538361571095921575989136588898',
                    'data': 'eyJsYW5nIjogImVuLXVzIiwgInNtcyI6IHRydWUsICJlbWFpbCI6IHRydWUsICJwdXNoIjogdHJ1ZX0=',
                    'approximateArrivalTimestamp': 1545084650.987
                },
                'eventSource': 'aws:kinesis',
                'eventVersion': '1.0',
                'eventID': 'shardId-000000000006:49590338271490256608559692538361571095921575989136588898',
                'eventName': 'aws:kinesis:record',
                'invokeIdentityArn': 'arn:aws:iam::123456789012:role/lambda-role',
                'awsRegion': 'us-east-2',
                'eventSourceARN': 'arn:aws:kinesis:us-east-2:123456789012:stream/lambda-stream'
            }
        ]
    }
